##  Overview
The SAP LeanIX App for Microsoft Teams is an application created to receive notifications in Microsoft Teams about updates in your SAP LeanIX workspace. The SAP LeanIX App for Microsoft Teams replaces the SAP LeanIX Notifications App. With the SAP LeanIX App, users can authenticate using their SAP LeanIX credentials within Microsoft Teams, enabling them to receive workspace notifications and get responses to basic workspace queries.
This page provides guidance on configuring the integration of Microsoft Teams in SAP LeanIX and adding the SAP LeanIX App to Microsoft Teams.
**Note**
All data exchange in the SAP LeanIX Teams app occurs through the EU region. We also securely store the tenant ID and conversation to support user-specific notifications.
